pub enum CreateClusterError {
Client(String),
InvalidParameter(String),
ResourceInUse(String),
ResourceLimitExceeded(String),
Server(String),
ServiceUnavailable(String),
UnsupportedAvailabilityZone(String),
}Expand description
Errors returned by CreateCluster
Variants
Client(String)
These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
InvalidParameter(String)
The specified parameter is invalid. Review the available parameters for the API request.
ResourceInUse(String)
The specified resource is in use.
ResourceLimitExceeded(String)
You have encountered a service limit on the specified resource.
Server(String)
These errors are usually caused by a server-side issue.
The service is unavailable. Back off and retry the operation.
UnsupportedAvailabilityZone(String)
At least one of your specified cluster subnets is in an Availability Zone that does not support Amazon EKS. The exception output specifies the supported Availability Zones for your account, from which you can choose subnets for your cluster.
Implementations
Sourceimpl CreateClusterError
impl CreateClusterError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateClusterError>