pub enum UpdateNodegroupConfigError {
Client(String),
InvalidParameter(String),
InvalidRequest(String),
ResourceInUse(String),
ResourceNotFound(String),
Server(String),
}Expand description
Errors returned by UpdateNodegroupConfig
Variants
Client(String)
These errors are usually caused by a client action. Actions can include using an action or resource on behalf of a user that doesn't have permissions to use the action or resource or specifying an identifier that is not valid.
InvalidParameter(String)
The specified parameter is invalid. Review the available parameters for the API request.
InvalidRequest(String)
The request is invalid given the state of the cluster. Check the state of the cluster and the associated operations.
ResourceInUse(String)
The specified resource is in use.
ResourceNotFound(String)
The specified resource could not be found. You can view your available clusters with ListClusters. You can view your available managed node groups with ListNodegroups. Amazon EKS clusters and node groups are Region-specific.
Server(String)
These errors are usually caused by a server-side issue.
Implementations
Sourceimpl UpdateNodegroupConfigError
impl UpdateNodegroupConfigError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<UpdateNodegroupConfigError>